package h658;

import java.util.List;
import java.util.Map;
import org.hornetq.api.core.TransportConfiguration;
import org.hornetq.core.config.Configuration;
import org.hornetq.core.config.CoreQueueConfiguration;
import org.hornetq.core.config.impl.ConfigurationImpl;
import org.hornetq.core.remoting.impl.netty.NettyAcceptorFactory;
import org.hornetq.core.remoting.impl.netty.TransportConstants;
import org.hornetq.core.server.HornetQServer;
import org.hornetq.core.server.HornetQServers;
import org.hornetq.spi.core.protocol.ProtocolType;

public class Server {

  public final static String QueueName = "jms.topic.demo";

  public static void main(String[] args) {
    try {
      // Embedded HornetQ bootstrap
      Configuration configuration = new ConfigurationImpl();

      // Mention another bug: HornetQ server doesn`t respect these settings,
      // "data/journal" directory is still created
      configuration.setPersistenceEnabled(false);
      configuration.setSecurityEnabled(false);
      // The settings below do not help: server fails on start() with
      // //java.lang.IllegalArgumentException: Directory data\journal does not exist and will not be created
      // // at org.hornetq.core.server.impl.HornetQServerImpl.checkJournalDirectory(HornetQServerImpl.java:1838)
      // // at org.hornetq.core.server.impl.HornetQServerImpl.start(HornetQServerImpl.java:518)
      //configuration.setCreateJournalDir(false);
      //configuration.setCreateBindingsDir(false);

      // Add STOMP acceptor
      final TransportConfiguration transport = new TransportConfiguration(NettyAcceptorFactory.class.getName());
      final Map<String, Object> params = transport.getParams();
      params.put(TransportConstants.PROTOCOL_PROP_NAME, ProtocolType.STOMP);
      params.put(TransportConstants.HOST_PROP_NAME, "0.0.0.0");
      params.put(TransportConstants.PORT_PROP_NAME, 61613);
      params.put(TransportConstants.USE_NIO_PROP_NAME, true);
      params.put(TransportConstants.TCP_NODELAY_PROPNAME, true);
      configuration.getAcceptorConfigurations().add(transport);
      // Configure default queues
      final List<CoreQueueConfiguration> queues = configuration.getQueueConfigurations();
      queues.add(new CoreQueueConfiguration(QueueName, QueueName, null, false));

      final HornetQServer server = HornetQServers.newHornetQServer(configuration, null, false);
      server.start();

      System.out.println("HornetQ started, press Enter to quit.");
      System.in.read();
      server.stop();
    } catch (Throwable e) {
      e.printStackTrace();
    }
  }

}
